@@ -73,6 +73,7 @@ class ChapelLexer(RegexLexer):
             (words(known_types, suffix=r'\b'), Keyword.Type),
             (words((*type_modifiers, *other_keywords), suffix=r'\b'), Keyword),
 
+            (r'@', Keyword, 'attributename'),
             (r'(iter)((?:\s)+)', bygroups(Keyword, Text), 'procname'),
             (r'(proc)((?:\s)+)', bygroups(Keyword, Text), 'procname'),
             (r'(operator)((?:\s)+)', bygroups(Keyword, Text), 'procname'),
@@ -134,4 +135,7 @@ class ChapelLexer(RegexLexer):
             (words(known_types, suffix=r'\b'), Keyword.Type),
             (r'[^()]*', Name.Other, '#pop'),
         ],
+        'attributename': [
+            (r'[a-zA-Z_][.\w$]*', Name.Decorator, '#pop'),
+        ],
     }
